searchData={"content_type":"text/markdown","items":[{"doc":"EmailAddress provides top-level parsing & formatting API to deal with RFC5322-formatted\ne-mail addresses and (in the future) lists of e-mail addresses.\n\nThis library is meant to be very forgiving and deal with invalid / malformed e-mail\naddresses in a fashion allowing for a recovery and avoiding common errors that happen\nwhen clients send malformed emails.","ref":"EmailAddress.html","title":"EmailAddress","type":"module"},{"doc":"Given `EmailAddress.Address` struct return RFC5322-formatted String containing\ne-mail address.\n\nThis function performs escaping and quoting special characters found in `display_name` if and only if\nrequired, leaving `display_name` unquoted in cases when it's not necessary.","ref":"EmailAddress.html#format/1","title":"EmailAddress.format/1","type":"function"},{"doc":"iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"\"})\n    \"jack.black@example.com\"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"})\n    \"Jack Black  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black's Email\"})\n    \"Jack Black's Email  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack   Email\"})\n    \"\\\"Jack   Email\\\"  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"jack.black@example.com\"})\n    \"\\\"jack.black@example.com\\\"  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\\\"\"})\n    \"\\\"Jack Black\\\\\\\"\\\"  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Black, Jack\"})\n    \"\\\"Black, Jack\\\"  \"","ref":"EmailAddress.html#format/1-examples","title":"Examples - EmailAddress.format/1","type":"function"},{"doc":"Given string containing single e-mail address, return `EmailAddress.Address` struct\ncontaining `addr_spec` and `display_name` fields or nil if address could not be\nparsed.","ref":"EmailAddress.html#parse/1","title":"EmailAddress.parse/1","type":"function"},{"doc":"iex> EmailAddress.parse(\"jack.black@example.com\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"\"}\n\n    iex> EmailAddress.parse(\"Jack Black  \")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    iex> EmailAddress.parse(\"\\\"Jack@Black\\\"  \")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack@Black\"}\n\n    iex> EmailAddress.parse(\"Jack Black jack.black@example.com\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    iex> EmailAddress.parse(\"Jack\\n\\rBlack\\tjack.black@example.com\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    iex> EmailAddress.parse(\"\\\"Jack@Black\\\"   \")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack@Black\"}\n\n    iex> EmailAddress.parse(\"\")\n    nil\n\n    iex> EmailAddress.parse(\"Not an email\")\n    nil\n\n    iex> EmailAddress.parse(\"http://example.com\")\n    nil\n\n    iex> EmailAddress.parse(\"notanemail\")\n    nil\n\n    iex> EmailAddress.parse(\" \")\n    nil\n\n    iex> EmailAddress.parse(\"Not an email  \")\n    nil\n\n    iex> EmailAddress.parse(\"Jack Black jack.black@example.com>\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    iex> EmailAddress.parse(\"Jack Black\\\" jack.black@example.com>\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\\\"\"}\n\n    iex> EmailAddress.parse(\"Jack.black@example.com jack.black@example.com\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack.black@example.com\"}\n\n    iex> EmailAddress.parse(\"Jack.black@example.com jack.black@example.com;,:\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack.black@example.com\"}\n\n    iex> EmailAddress.parse(\"Hubert Łępicki  \")\n    %EmailAddress.Address{addr_spec: \"hubert.łępicki@hubertłępicki.com\", display_name: \"Hubert Łępicki\"}\n\n    iex> EmailAddress.parse(\"Hubert Łępicki  \")\n    %EmailAddress.Address{addr_spec: \"hubert.łępicki@hubertłępicki.com\", display_name: \"Hubert Łępicki\"}\n\n    iex> EmailAddress.parse(\"client@example.com (Client Client)\")\n    %EmailAddress.Address{addr_spec: \"client@example.com\", display_name: \"Client Client\"}\n\n    iex> EmailAddress.parse(\"\\\"Black, Jack\\\"  \")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Black, Jack\"}\n\n    iex> EmailAddress.parse(\"\\\"Black, Jack\\\"  \")\n    %EmailAddress.Address{addr_spec: \"jack.black@127.0.0.1\", display_name: \"Black, Jack\"}\n\n    iex> EmailAddress.parse(\"\\\"=?UTF-8?Q?Tesorer=C3=ADa?=\\\"  \")\n    %EmailAddress.Address{addr_spec: \"user@u-oerre.md\", display_name: \"=?UTF-8?Q?Tesorer=C3=ADa?=\"}","ref":"EmailAddress.html#parse/1-examples","title":"Examples - EmailAddress.parse/1","type":"function"},{"doc":"","ref":"EmailAddress.Address.html","title":"EmailAddress.Address","type":"module"},{"doc":"# EmailAddress\n\nEmailAddress provides top-level parsing & formatting API to deal with RFC5322-formatted\ne-mail addresses.\n\nThis library is meant to be very forgiving and deal with invalid / malformed e-mail\naddresses in a fashion allowing for a recovery and avoiding common errors that happen\nwhen clients send malformed emails.\n\nThe case for having a forgiving library to parse e-mail addresses, is that the e-mail\nclients do not stick to the rules or have bugs allowing for invalid e-mail addresses to\nbe used when sending, receiving or processing e-mails.\n\nThis library defines e-mail address as a string, which contains what most people think as\nsender name + e-mail address.\n\nWhen parsing, we support various formats encountered in the wild:\n\n```\n- jack.black@example.com\n- Jack Black  \n- \"Jack@Black\"  \n- Jack Black jack.black@example.com\n- Jack\\n\\rBlack\\tjack.black@example.com\n- jack.black@example.com (Jack Black)\n- Jack Black  \n```","ref":"readme.html","title":"EmailAddress","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/packages/email_address), the package can be installed\nby adding `email_address` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:email_address, \"~> 1.0\"}\n  ]\nend\n```\n\nDocumentation can be can be found at\n[https://hexdocs.pm/email_address](https://hexdocs.pm/email_address).","ref":"readme.html#installation","title":"Installation - EmailAddress","type":"extras"},{"doc":"Parsing e-mail addresses:\n\n    EmailAddress.parse(\"jack.black@example.com\")\n    => %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"\"}\n\n    EmailAddress.parse(\"Jack Black  \")\n    => %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    EmailAddress.parse(\"Not an e-mail\")\n    => nil\n\nFormatting e-mail address:\n\n    EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"\"})\n    => \"jack.black@example.com\"\n\n    EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"})\n    => \"Jack Black  \"\n\n    EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack   Email\"})\n    => \"\\\\\"Jack   Email\\\\\"  \"","ref":"readme.html#usage","title":"Usage - EmailAddress","type":"extras"},{"doc":"This code has been made open source thanks to [Keeping.com](https://keeping.com). Please check them out if you need a shared Gmail inbox!","ref":"readme.html#thanks","title":"Thanks - EmailAddress","type":"extras"},{"doc":"Copyright (c) 2024, Hubert Łępicki.\n\nEmailAddress source code is licensed under the [MIT License](LICENSE.md).","ref":"readme.html#copyright-and-license","title":"Copyright and License - EmailAddress","type":"extras"},{"doc":"# CHANGELOG\n\nv1.0.0\n- 2024-02-23 Initial release","ref":"changelog.html","title":"CHANGELOG","type":"extras"},{"doc":"# MIT License\n\nCopyright (c) 2018 Chris McCord\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"MIT License","type":"extras"}]}